@@ -45,8 +45,8 @@ static TDECmdLineOptions options[] =
 
 void findAloneWindow()
 {
-	unsigned int numkids, i,mapped,scrn;
-	Window r, p;
+	unsigned int numkids, scrn;
+	Window root_id, parent_id;
 	Window *kids=0;
 	//XWindowAttributes attr;
 	Window root;
@@ -59,11 +59,11 @@ void findAloneWindow()
 	scrn = DefaultScreen(dipsy);
 	root = RootWindow(dipsy, scrn);
 	
-	mapped = 0;
-	XQueryTree(dipsy, root, &r, &p, &kids, &numkids);
+	
+	XQueryTree(dipsy, root, &root_id, &parent_id, &kids, &numkids);
 		
 
-	for (i = 0; i < numkids;  ++i)
+	for (unsigned int i = 0; i < numkids;  ++i)
 	{
 			XFetchName(dipsy, kids[i], &win_name);
 			TQString c(win_name);
